from django.core.management.base import BaseCommand, CommandError
from arkindex.project.argparse import RepositoryArgument
from arkindex.dataimport.models import DataImport, DataImportMode


class Command(BaseCommand):
    help = 'Create a DataImport to use a git repo'

    def add_arguments(self, parser):
        parser.add_argument(
            'repo',
            type=RepositoryArgument(),
            help='ID or part of the URL of the repository to check on',
        )
        parser.add_argument(
            '--hash',
            help='Hash of a revision in the repository to check on. Defaults to latest commit on master',
            default=None,
        )

    def handle(self, *args, repo=None, **options):
        if repo.provider_class is None:
            raise CommandError("No repository provider found for {}".format(repo.url))

        if 'hash' in options and options['hash'] is not None:
            rev, created = repo.provider.get_or_create_revision(repo, options['hash'])
        else:
            rev, created = repo.provider.get_or_create_latest_revision(repo)

        if created:
            self.stdout.write('Created revision {} "{}" on repository {}'.format(rev.hash, rev.message, repo.url))

        di = DataImport.objects.create(
            creator=repo.credentials.user,
            corpus=repo.corpus,
            mode=DataImportMode.Repository,
            revision=rev,
        )
        di.start()

        self.stdout.write(self.style.SUCCESS('Successfully built DataImport {}'.format(di)))
        self.stdout.write('To test the import manually, run: ./manage.py import {}'.format(di.id))
