from django.conf import settings
from ponos.management.base import PonosCommand, FolderArgument
from arkindex.project.argparse import CorpusArgument
from arkindex.documents.surface import SurfaceImporter
from arkindex.documents.surface_link import CorpusSurfaceLinker
import logging

logging.basicConfig(
    format='[%(levelname)s] %(message)s',
    level=logging.INFO,
)


class Command(PonosCommand):
    help = "Import surfaces and Himanis acts from XML+CSV files"
    docker_image = settings.ARKINDEX_APP_IMAGE
    base_recipe = settings.PONOS_RECIPE

    def add_arguments(self, parser):
        super().add_arguments(parser)
        parser.add_argument(
            'xml',
            type=FolderArgument(),
            help='Path to a folder containing XML files for surfaces, structured in subfolders for each volume.',
        )
        parser.add_argument(
            'csv',
            help='Path to a folder containing CSV files with surface-act associations, named after the volumes.',
            type=FolderArgument(),
        )
        parser.add_argument(
            '--corpus',
            type=CorpusArgument(),
            help='ID or part of the name of a corpus to import surfaces into.',
            required=True,
        )
        parser.add_argument(
            '--dry-run',
            action='store_true',
            default=False,
            help='Print matched images for each surface file without importing.',
        )
        parser.add_argument(
            '--col-number',
            default=0,
            type=int,
            help='Column index for number'
        )
        parser.add_argument(
            '--col-folio',
            default=1,
            type=int,
            help='Column index for folio'
        )

    def run(self, **options):
        importer = SurfaceImporter(xmlpath=options['xml'], corpus=options['corpus'])
        importer.run(options['dry_run'])

        importer = CorpusSurfaceLinker(csvpath=options['csv'], corpus=options['corpus'])
        importer.run(options['dry_run'])
