# Generated by Django 2.1 on 2019-02-12 16:10

import arkindex.documents.models
import arkindex.project.fields
import arkindex_common.ml_tool
import django.contrib.postgres.indexes
from django.db import migrations, models
import django.db.models.deletion
import enumfields.fields
import uuid


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('dataimport', '0001_initial'),
        ('images', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='Classification',
            fields=[
                ('id', models.UUIDField(default=uuid.uuid4, primary_key=True, serialize=False)),
                ('class_name', models.CharField(max_length=100)),
                ('confidence', models.FloatField(blank=True, null=True)),
            ],
        ),
        migrations.CreateModel(
            name='Corpus',
            fields=[
                ('id', models.UUIDField(default=uuid.uuid4, primary_key=True, serialize=False)),
                ('name', models.CharField(max_length=250)),
                ('description', models.TextField(default='')),
                ('public', models.BooleanField(default=False)),
            ],
            options={
                'verbose_name_plural': 'corpora',
            },
        ),
        migrations.CreateModel(
            name='DataSource',
            fields=[
                ('id', models.UUIDField(default=uuid.uuid4, primary_key=True, serialize=False)),
                ('type', enumfields.fields.EnumField(enum=arkindex_common.ml_tool.MLToolType, max_length=10)),
                ('slug', models.CharField(max_length=100)),
                ('revision', models.CharField(max_length=100)),
                ('internal', models.BooleanField()),
            ],
        ),
        migrations.CreateModel(
            name='Element',
            fields=[
                ('id', models.UUIDField(default=uuid.uuid4, primary_key=True, serialize=False)),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('updated', models.DateTimeField(auto_now=True)),
                ('type', enumfields.fields.EnumField(db_index=True, enum=arkindex.documents.models.ElementType, max_length=50)),
                ('name', models.CharField(max_length=250)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='ElementPath',
            fields=[
                ('id', models.UUIDField(default=uuid.uuid4, primary_key=True, serialize=False)),
                ('path', arkindex.project.fields.ArrayField(base_field=models.UUIDField(), size=None)),
                ('ordering', models.PositiveIntegerField(default=0)),
            ],
        ),
        migrations.CreateModel(
            name='MetaData',
            fields=[
                ('id', models.UUIDField(default=uuid.uuid4, primary_key=True, serialize=False)),
                ('name', models.CharField(max_length=250)),
                ('type', enumfields.fields.EnumField(db_index=True, enum=arkindex.documents.models.MetaType, max_length=50)),
                ('value', models.TextField()),
                ('index', models.PositiveIntegerField(default=0)),
            ],
            options={
                'ordering': ('element', 'name', 'index'),
            },
        ),
        migrations.CreateModel(
            name='Transcription',
            fields=[
                ('id', models.UUIDField(default=uuid.uuid4, primary_key=True, serialize=False)),
                ('type', enumfields.fields.EnumField(db_index=True, default='word', enum=arkindex.documents.models.TranscriptionType, max_length=50)),
                ('text', models.TextField(blank=True, null=True)),
                ('score', models.FloatField(blank=True, null=True)),
            ],
        ),
        migrations.CreateModel(
            name='Act',
            fields=[
                ('element_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, serialize=False, to='documents.Element')),
                ('number', models.CharField(max_length=30)),
                ('folio', models.CharField(max_length=250)),
            ],
            options={
                'abstract': False,
            },
            bases=('documents.element',),
        ),
        migrations.CreateModel(
            name='Page',
            fields=[
                ('element_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, serialize=False, to='documents.Element')),
                ('folio', models.CharField(max_length=250)),
                ('page_type', enumfields.fields.EnumField(blank=True, enum=arkindex.documents.models.PageType, max_length=50, null=True)),
                ('nb', models.PositiveIntegerField(blank=True, null=True)),
                ('direction', enumfields.fields.EnumField(blank=True, enum=arkindex.documents.models.PageDirection, max_length=10, null=True)),
                ('complement', enumfields.fields.EnumField(blank=True, enum=arkindex.documents.models.PageComplement, max_length=10, null=True)),
            ],
            options={
                'abstract': False,
            },
            bases=('documents.element',),
        ),
        migrations.AddField(
            model_name='transcription',
            name='element',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='transcriptions', to='documents.Element'),
        ),
        migrations.AddField(
            model_name='transcription',
            name='source',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='transcriptions', to='documents.DataSource'),
        ),
        migrations.AddField(
            model_name='transcription',
            name='zone',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='transcriptions', to='images.Zone'),
        ),
        migrations.AddField(
            model_name='metadata',
            name='element',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='metadatas', to='documents.Element'),
        ),
        migrations.AddField(
            model_name='metadata',
            name='revision',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='dataimport.Revision'),
        ),
        migrations.AddField(
            model_name='elementpath',
            name='element',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='paths', to='documents.Element'),
        ),
        migrations.AddField(
            model_name='element',
            name='corpus',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='elements', to='documents.Corpus'),
        ),
        migrations.AddField(
            model_name='element',
            name='zone',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='elements', to='images.Zone'),
        ),
        migrations.AlterUniqueTogether(
            name='datasource',
            unique_together={('type', 'slug', 'revision')},
        ),
        migrations.AddField(
            model_name='classification',
            name='source',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='classifications', to='documents.DataSource'),
        ),
        migrations.AlterUniqueTogether(
            name='metadata',
            unique_together={('element', 'name', 'index')},
        ),
        migrations.AddIndex(
            model_name='elementpath',
            index=django.contrib.postgres.indexes.GinIndex(fields=['path'], name='documents_e_path_15a4b8_gin'),
        ),
        migrations.AddField(
            model_name='classification',
            name='page',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='classifications', to='documents.Page'),
        ),
        migrations.AlterUniqueTogether(
            name='classification',
            unique_together={('page', 'source', 'class_name')},
        ),
    ]
