from rest_framework import serializers
from arkindex.documents.models import Element, ElementType, Corpus, Page, PageType, PageDirection
from arkindex.documents.serializers.ml import ClassificationSerializer
from arkindex.images.serializers import ImageSerializer
from arkindex.project.serializer_fields import EnumField


class ElementLightSerializer(serializers.ModelSerializer):
    """
    Serialises a Element
    """
    type = EnumField(ElementType)

    class Meta:
        model = Element
        fields = (
            'id',
            'type',
            'name',
        )


class PageLightSerializer(serializers.ModelSerializer):
    """
    Serialises a Page
    """
    page_type = EnumField(PageType)
    direction = EnumField(PageDirection)
    image = ImageSerializer(source='zone.image')
    best_classes = ClassificationSerializer(many=True)

    class Meta:
        model = Page
        fields = (
            'id',
            'page_type',
            'nb',
            'direction',
            'display_name',
            'image',
            'best_classes',
        )


class CorpusLightSerializer(serializers.ModelSerializer):
    """
    Serializes a Corpus
    """

    class Meta:
        model = Corpus
        fields = (
            'id',
            'name',
            'public'
        )
