from django.core.management import call_command
from unittest.mock import patch, call
from arkindex_common.ml_tool import MLToolType
from arkindex.project.tests import FixtureTestCase
from arkindex.documents.models import DataSource
import tempfile
import shutil


class TestImportAnnotationsCommand(FixtureTestCase):
    """
    Test the import_annotations command.
    """

    @classmethod
    def setUpTestData(cls):
        super().setUpTestData()
        cls.source = DataSource.objects.get(type=MLToolType.Recognizer, slug='test')

    @classmethod
    def setUpClass(cls):
        super().setUpClass()
        cls.importer_mock = patch('arkindex.documents.management.commands.import_annotations.IndexImporter').start()
        cls.tmpdir = tempfile.mkdtemp()

    @classmethod
    def tearDownClass(cls):
        super().tearDownClass()
        shutil.rmtree(cls.tmpdir)

    def setUp(self):
        super().setUp()
        self.importer_mock.reset_mock()

    def test_start(self):
        """
        Test import_annotations runs the IndexImporter
        """
        call_command(
            'import_annotations',
            self.tmpdir,
            corpus=str(self.corpus.id),
            source=str(self.source.id),
        )
        self.assertEqual(self.importer_mock.call_count, 1)
        self.assertEqual(
            self.importer_mock.call_args,
            call(self.tmpdir, corpus=str(self.corpus.id), source=str(self.source.id)),
        )
        self.assertEqual(self.importer_mock().run.call_count, 1)
        self.assertEqual(self.importer_mock().dry_run.call_count, 0)

    def test_dry_run(self):
        """
        Test import_annotations passes the dry run parameter to IndexImporter
        """
        call_command(
            'import_annotations',
            self.tmpdir,
            corpus=str(self.corpus.id),
            source=str(self.source.id),
            dry_run=True,
        )
        self.assertEqual(self.importer_mock.call_count, 1)
        self.assertEqual(
            self.importer_mock.call_args,
            call(self.tmpdir, corpus=str(self.corpus.id), source=str(self.source.id)),
        )
        self.assertEqual(self.importer_mock().run.call_count, 0)
        self.assertEqual(self.importer_mock().dry_run.call_count, 1)
