from arkindex.project.tests import FixtureTestCase
from arkindex.project.polygon import Polygon
from arkindex.documents.models import Element, ElementType, Page
from arkindex.documents.surface import SurfaceImporter
import os.path

FIXTURES = os.path.join(
    os.path.dirname(os.path.realpath(__file__)),
    'surface_importer_samples',
)


class TestSurfaceLinker(FixtureTestCase):

    @classmethod
    def setUpTestData(cls):
        super().setUpTestData()
        cls.volume = Element.objects.get(type=ElementType.Volume, name='Volume 1')
        cls.page1r = Page.objects.get(name='Volume 1, page 1r')
        cls.page1v = Page.objects.get(name='Volume 1, page 1v')

    def test_import(self):
        """
        Run an actual import with no mocks
        """
        surfaces = Element.objects.get_descending(self.volume.id, type=ElementType.Surface).order_by('name')
        # Remove any surface on the volume
        surfaces.delete()

        si = SurfaceImporter(FIXTURES, corpus=self.corpus)
        si.run()

        self.assertEqual(surfaces.count(), 3)
        s1, s2, s3 = surfaces

        self.assertQuerysetEqual(
            Element.objects.get_descending(self.page1r.id, type=ElementType.Surface),
            [repr(s1), ],
        )
        self.assertQuerysetEqual(
            Element.objects.get_descending(self.page1v.id, type=ElementType.Surface).order_by('name'),
            map(repr, [s2, s3]),
        )
        self.assertEqual(s1.zone.image, self.page1r.zone.image)
        self.assertEqual(s2.zone.image, self.page1v.zone.image)
        self.assertEqual(s3.zone.image, self.page1v.zone.image)
        self.assertEqual(s1.name, 'Surface TextRegion_1500465748446_12')
        self.assertEqual(s2.name, 'Surface TextRegion_1522155769847_481')
        self.assertEqual(s3.name, 'Surface TextRegion_1522155769847_482')
        self.assertEqual(s1.zone.polygon, Polygon(((2974, 1270), (16, 1270), (18, 105), (2976, 105))))
        self.assertEqual(s2.zone.polygon, Polygon(((3509, 4569), (0, 4569), (0, 1675), (3509, 1675))))
        self.assertEqual(s3.zone.polygon, Polygon(((3509, 1675), (0, 1675), (0, 0), (3509, 0))))
