from unittest import TestCase
from arkindex.documents.surface import SurfaceParser
from arkindex.project.polygon import Polygon
import os.path

FIXTURES = os.path.join(
    os.path.dirname(os.path.realpath(__file__)),
    'surface_samples',
)


class TestSurfaceParser(TestCase):
    # TODO: Make these tests readable!

    def test_surface_simple(self):
        s = SurfaceParser(os.path.join(FIXTURES, 'simple.xml'))

        # Check metadata
        meta = s.get_metadata()
        self.assertEqual(meta['imageFilename'], 'FRAN_0021_0023_L.jpg')
        self.assertEqual(meta['imageWidth'], '3195')
        self.assertEqual(meta['imageHeight'], '3731')
        self.assertEqual(meta['creator'], 'TRP')
        self.assertEqual(meta['created'], '2017-07-19T13:58:10.738+02:00')
        self.assertEqual(meta['lastchange'], '2017-07-19T14:04:22.502+02:00')
        # Check surfaces
        surfaces = s.list_surfaces()
        self.assertEqual(surfaces[0]['id'], 'TextRegion_1500465748446_12')
        self.assertEqual(surfaces[0]['index'], 0)
        self.assertEqual(surfaces[0]['polygon'], Polygon([(2974, 1270), (16, 1270), (18, 105), (2976, 105)]))

    def test_surface_2_regions(self):
        s = SurfaceParser(os.path.join(FIXTURES, '2_regions.xml'))

        # Check metadata
        meta = s.get_metadata()
        self.assertEqual(meta['imageFilename'], 'FRAN_0021_0316_L.jpg')
        self.assertEqual(meta['imageWidth'], '3509')
        self.assertEqual(meta['imageHeight'], '4569')
        self.assertEqual(meta['creator'], 'TRP')
        self.assertEqual(meta['created'], '2018-03-27T13:03:11.218+02:00')
        self.assertEqual(meta['lastchange'], '2018-03-27T15:02:50.831+02:00')
        # Check surfaces
        surfaces = s.list_surfaces()
        self.assertEqual(surfaces[0]['id'], 'TextRegion_1522155769847_482')
        self.assertEqual(surfaces[0]['index'], 0)
        self.assertEqual(surfaces[0]['polygon'], Polygon([(3509, 1675), (0, 1675), (0, 0), (3509, 0)]))
        self.assertEqual(surfaces[1]['id'], 'TextRegion_1522155769847_481')
        self.assertEqual(surfaces[1]['index'], 1)
        self.assertEqual(surfaces[1]['polygon'], Polygon([(3509, 4569), (0, 4569), (0, 1675), (3509, 1675)]))

    def test_surface_unordered(self):
        s = SurfaceParser(os.path.join(FIXTURES, 'unordered.xml'))

        # Check metadata
        meta = s.get_metadata()
        self.assertEqual(meta['imageFilename'], 'FRAN_0021_0316_L.jpg')
        self.assertEqual(meta['imageWidth'], '3509')
        self.assertEqual(meta['imageHeight'], '4569')
        self.assertEqual(meta['creator'], 'TRP')
        self.assertEqual(meta['created'], '2018-03-27T13:03:11.218+02:00')
        self.assertEqual(meta['lastchange'], '2018-03-27T15:02:50.831+02:00')
        # Check surfaces
        surfaces = s.list_surfaces()
        self.assertEqual(surfaces[0]['id'], 'TextRegion_1522155769847_482')
        self.assertEqual(surfaces[0]['index'], 0)
        self.assertEqual(surfaces[0]['polygon'], Polygon([(3509, 1675), (0, 1675), (0, 0), (3509, 0)]))
        self.assertEqual(surfaces[1]['id'], 'TextRegion_1522155769847_481')
        self.assertEqual(surfaces[1]['index'], 1)
        self.assertEqual(surfaces[1]['polygon'], Polygon([(3509, 4569), (0, 4569), (0, 1675), (3509, 1675)]))
        self.assertEqual(surfaces[2]['id'], "TextRegion_1522155769847_484")
        self.assertEqual(surfaces[2]['index'], 2)
        self.assertEqual(surfaces[2]['polygon'], Polygon([(3509, 4569), (0, 4569), (0, 1675), (3509, 1675)]))

    def test_surface_no_reading_order(self):
        "Test SurfaceParser with no ReadingOrder tag in XML file"
        surfaces = SurfaceParser(os.path.join(FIXTURES, 'no_reading_order.xml')).list_surfaces()
        self.assertEqual(surfaces[0]['id'], 'TextRegion_1522155769847_482')
        self.assertEqual(surfaces[0]['index'], 0)
        self.assertEqual(surfaces[0]['polygon'], Polygon([(3509, 1675), (0, 1675), (0, 0), (3509, 0)]))
        self.assertEqual(surfaces[1]['id'], 'TextRegion_1522155769847_481')
        self.assertEqual(surfaces[1]['index'], 1)
        self.assertEqual(surfaces[1]['polygon'], Polygon([(3509, 4569), (0, 4569), (0, 1675), (3509, 1675)]))
        self.assertEqual(surfaces[2]['id'], "TextRegion_1522155769847_484")
        self.assertEqual(surfaces[2]['index'], 2)
        self.assertEqual(surfaces[2]['polygon'], Polygon([(3509, 4569), (0, 4569), (0, 1675), (3509, 1675)]))
