from django.contrib import admin
from django.urls import path
from arkindex.images.models import ImageServer, Image
from arkindex.images.views import ImageServerMergeView, ImageServerSplitView
from enumfields.admin import EnumFieldListFilter


class ImageServerAdmin(admin.ModelAdmin):
    list_display = ('display_name', 'url', 'validated')

    def get_urls(self):
        # Give views access to this ModelAdmin instance
        ImageServerMergeView.model_admin = self
        ImageServerSplitView.model_admin = self

        urls = super().get_urls()
        return [
            path(
                '<id>/merge/',
                self.admin_site.admin_view(ImageServerMergeView.as_view()),
                name='images_imageserver_merge',
            ),
            path(
                '<id>/split/',
                self.admin_site.admin_view(ImageServerSplitView.as_view()),
                name='images_imageserver_split',
            )
        ] + urls


class ImageAdmin(admin.ModelAdmin):
    list_display = ('path', 'server', 'width', 'height', 'status')
    list_filter = (
        ('server', admin.RelatedFieldListFilter),
        ('status', EnumFieldListFilter),
    )
    fields = ('id', 'server', 'path', 'width', 'height', 'status')
    readonly_fields = ('id', )


admin.site.register(ImageServer, ImageServerAdmin)
admin.site.register(Image, ImageAdmin)
