from arkindex.project.tests import FixtureTestCase
from django.test import override_settings
from io import BytesIO
from unittest.mock import patch, call


class TestImage(FixtureTestCase):

    def test_path_not_encoded(self):
        """
        Assert that an image's path is not URL encoded when created
        This can yield to images with URLs such as http://.../test%34test to be encoded as http://.../test%2534test
        """
        img = self.imgsrv.images.create(path='!#%:+/*')
        img.refresh_from_db()
        self.assertEqual(img.path, '!#%:+/*')
        self.assertEqual(img.url, 'http://server/!#%:+/*')

    @override_settings(LOCAL_IMAGESERVER_ID=-1, IIIF_DOWNLOAD_TIMEOUT=(13, 37))
    @patch('arkindex.images.models.PillowImage.open')
    @patch('arkindex.images.models.requests.get')
    def test_pillow_open_url(self, get_mock, pillow_open_mock):
        self.assertFalse(self.imgsrv.is_local)
        img = self.imgsrv.images.create(path='image')
        get_mock.return_value.content = b'imageblob'
        self.assertEqual(img.pillow_open(), pillow_open_mock.return_value)
        self.assertEqual(get_mock.call_count, 1)
        self.assertEqual(get_mock.call_args, call('http://server/image/full/500,/0/default.jpg', timeout=(13, 37)))
        self.assertEqual(get_mock().raise_for_status.call_count, 1)
        self.assertEqual(pillow_open_mock.call_count, 1)
        args, kwargs = pillow_open_mock.call_args
        self.assertDictEqual(kwargs, {})
        self.assertEqual(len(args), 1)
        self.assertIsInstance(args[0], BytesIO)
        self.assertEqual(args[0].read(), b'imageblob')

    def test_build_url(self):
        self.assertEqual(self.imgsrv.build_url('some/path'), 'http://server/some/path')
        self.assertEqual(self.imgsrv.build_url('/some/path'), 'http://server/some/path')
        # Should handle paths that look like an absolute URL but aren't
        self.assertEqual(self.imgsrv.build_url('ark:/some/path'), 'http://server/ark:/some/path')
