from django.conf import settings
from rest_framework import permissions


class InternalGroupPermissionMixin(object):

    def has_permission(self, request, view):
        if request.user.is_authenticated and not request.user.is_admin:
            # Get the domain part from the request;
            # ignore the port as it is not included in INTERNAL_HOSTS
            host = request.get_host().partition(':')[0]

            # If the user is for internal requests but the request comes from outside,
            # or if the user is not for internal requests but the request is from the inside
            if request.user.is_internal ^ (host in settings.INTERNAL_HOSTS):
                return False

        return super().has_permission(request, view)


class DemoGroupPermissionMixin(object):

    def has_permission(self, request, view):
        if request.user.is_authenticated and not request.user.is_admin:
            # If the user has registered from the demo, or has an unverified email,
            # only allow HEAD, GET and OPTIONS.
            if not request.user.verified_email or request.user.is_demo:
                return super().has_permission(request, view) and request.method in permissions.SAFE_METHODS

        return super().has_permission(request, view)


class AllowAny(InternalGroupPermissionMixin, permissions.AllowAny):
    pass


class IsAuthenticated(InternalGroupPermissionMixin, permissions.IsAuthenticated):
    pass


class IsAuthenticatedOrReadOnly(InternalGroupPermissionMixin, permissions.IsAuthenticatedOrReadOnly):
    pass


class IsAdminUser(InternalGroupPermissionMixin, permissions.IsAdminUser):
    pass


class IsVerified(DemoGroupPermissionMixin, IsAuthenticated):
    pass


class IsVerifiedOrReadOnly(DemoGroupPermissionMixin, IsAuthenticatedOrReadOnly):
    pass
